@@ -58,7 +58,7 @@ def check_open_orders(orders_list):
 
             for order in orders_list:
                 trade_symbol = order["tradingsymbol"]
-                if order["trade_type"] == "ENTRY":
+                if order["trade_action"] == "ENTRY":
                     # Adding Must Have Fields
                     quantity_dict[trade_symbol]["buy_quantity"] = order["quantity"]
                     quantity_dict[trade_symbol]["quantity"] = order["quantity"]
@@ -75,10 +75,13 @@ def check_open_orders(orders_list):
                     quantity_dict[trade_symbol]["trailing_sl"] = order.get("trailing_sl", "")
                     quantity_dict[trade_symbol]["t1_price"] = order.get("t1_price", "")
                     quantity_dict[trade_symbol]["sl_price"] = order.get("sl_price", "")
+                    quantity_dict[trade_symbol]["t2_price"] = order.get("t2_price", "")
+                    quantity_dict[trade_symbol]["t3_price"] = order.get("t3_price", "")
+                    quantity_dict[trade_symbol]["liquidation_price"] = order.get("liquidation_price", "")
                     quantity_dict[trade_symbol]["hka_option_order_price"] = order.get("hka_option_order_price", "")
                     quantity_dict[trade_symbol]["option_order_price"] = order.get("option_order_price", "")
 
-                elif order["trade_type"] == "EXIT":
+                elif order["trade_action"] == "EXIT":
                     quantity_dict[trade_symbol]["sell_quantity"] += order["quantity"]
                     quantity_dict[trade_symbol]["quantity_left"] = order["quantity_left"]
                     quantity_dict[trade_symbol]["exit_levels"].append(order["exit_type"])
@@ -106,7 +109,7 @@ def convert_to_trades(orders_list, market_type, order_exit_levels, mode, broker)
                 trade_dict["date"] = order["date"]
                 trade_dict["stock"] = order["tradingsymbol"]
                 trade_dict["lot_size"] = order["lot_size"]
-                trade_dict["trade_type"] = order["trade_type"]
+                trade_dict["position_type"] = order.get("position_type", "LONG")
                 trade_dict["bnf_price"] = order.get("bnf_price", "")
                 trade_dict["bar_color"] = order["bar_color"]
                 trade_dict["entry_time"] = order["order_timestamp"]
@@ -135,7 +138,7 @@ def convert_to_trades(orders_list, market_type, order_exit_levels, mode, broker)
 
             else:
                 if market_type == "spot" or market_type == "futures":
-                    if order["trade_type"] == "SHORT":
+                    if order["position_type"] == "SHORT":
                         points = trade_dict["entry_price"] - order["trigger_price"]
                         trade_dict["points"] += round(points)
                         trade_dict["pnl"] += round(order["quantity"] * points)
