@@ -520,11 +520,11 @@ def apply_indicators(dataframe, indicators_dict):
             dataframe["ecr"] = ecr_values.tolist()
 
         if "STOCH" in indicators_dict:
-            stoch_df = stochastic_oscillator(dataframe=dataframe, k=indicators_dict["STOCH"]["k"], d=indicators_dict["STOCH"]["d"],
-                                             smooth_k=indicators_dict["STOCH"]["smooth"])
+            # stoch_df = stochastic_oscillator(dataframe=dataframe, k=indicators_dict["STOCH"]["k"], d=indicators_dict["STOCH"]["d"],
+            #                                  smooth_k=indicators_dict["STOCH"]["smooth"])
 
-            # stoch_df = TA.stoch(high=dataframe["high"], low=dataframe["low"], close=dataframe["close"],
-            #                     k=indicators_dict["STOCH"]["k"], d=indicators_dict["STOCH"]["d"], smooth_k=indicators_dict["STOCH"]["smooth"], offset=0)
+            stoch_df = TA.stoch(high=dataframe["high"], low=dataframe["low"], close=dataframe["close"],
+                                k=indicators_dict["STOCH"]["k"], d=indicators_dict["STOCH"]["d"], smooth_k=indicators_dict["STOCH"]["smooth"], offset=0)
             stoch_k = round(stoch_df.iloc[:, 0], 2).fillna(0).values
             stoch_d = round(stoch_df.iloc[:, 1], 2).fillna(0).values
             dataframe["stoch_k"] = stoch_k
@@ -674,7 +674,7 @@ def apply_indicators(dataframe, indicators_dict):
             dataframe["smi_o"] = round(smi_df.iloc[:, 2], 2).fillna(0).values
 
         if "MCGD" in indicators_dict:
-            mcgd_df = mcgd(close=dataframe["close"], length=indicators_dict["MCGD"]["length"])
+            mcgd_df = TA.mcgd(close=dataframe["close"], length=indicators_dict["MCGD"]["length"])
             dataframe["mcgd"] = round(mcgd_df.iloc[:], 2).fillna(0).values
 
         if "TPR" in indicators_dict:
@@ -838,9 +838,9 @@ def apply_indicators(dataframe, indicators_dict):
             slope_df = calculate_slope(dataframe=dataframe, source=indicators_dict["SLOPE"]["source"])
             dataframe[f'{indicators_dict["SLOPE"]["source"]}_slope'] = slope_df.iloc[:, 0]
 
-        if "MCGD" in indicators_dict:
-            mcgd_df = mcgd(close=dataframe["close"], length=indicators_dict["MCGD"]["length"])
-            dataframe["mcgd"] = round(mcgd_df, 2).fillna(0).values
+        # if "MCGD" in indicators_dict:
+        #     mcgd_df = mcgd(close=dataframe["close"], length=indicators_dict["MCGD"]["length"])
+        #     dataframe["mcgd"] = round(mcgd_df, 2).fillna(0).values
 
         if "AO" in indicators_dict:
             ao_df = TA.ao(high=dataframe["high"], low=dataframe["low"])
@@ -1663,6 +1663,9 @@ def generate_mt_report(report_df, pnl_column='net_pnl'):
     try:
         print("Generating MT Report")
         out_dict = {}
+        print(f"report_df : ")
+        print(report_df.head())
+
         initial_deposit = report_df['investment'][0]
 
         # Total trades
@@ -1910,22 +1913,22 @@ def calculate_roi_percent(entry_price, current_price):
         pass
 
 
-def calculate_liquidation_price(entry_price, leverage=10, trade_type="LONG", mmr=0.005):
+def calculate_liquidation_price(entry_price, leverage=10, position_type="LONG", mmr=0.005):
     """ Function to Calculate Liquidation Price"""
     try:
         if leverage <= 1:
             return None
 
-        trade_type = trade_type.upper()
+        position_type = position_type.upper()
 
-        if trade_type == "LONG":
+        if position_type == "LONG":
             denominator = leverage + 1 - (mmr * leverage)
             liquidation_price = (entry_price * leverage) / denominator
-        elif trade_type == "SHORT":
+        elif position_type == "SHORT":
             denominator = leverage - 1 + (mmr * leverage)
             liquidation_price = (entry_price * leverage) / denominator
         else:
-            raise ValueError("trade_type must be 'LONG' or 'SHORT'")
+            raise ValueError("position_type must be 'LONG' or 'SHORT'")
 
         return round(liquidation_price, 2)
     except Exception as e:
